@@ -1,11 +1,13 @@
 import click
 
 import sym.flow.cli.helpers.output as cli_output
+from sym.flow.cli.errors import SymAPIRequestError, UnknownBotError
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 from sym.flow.cli.models import ServiceType
 
 
-@click.command(name="delete", short_help="Delete a Sym Bot User")
+@click.command(cls=TrackedCommand, name="delete", short_help="Delete a Sym Bot User")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @click.argument("username")
 @click.option(
@@ -37,5 +39,9 @@ def bots_delete(options: GlobalOptions, username: str, force: bool) -> None:
         ]
     }
 
-    options.sym_api.delete_user(payload)
+    try:
+        options.sym_api.delete_user(payload)
+    except SymAPIRequestError as e:
+        if e.response_code == 404:
+            raise UnknownBotError(username)
     cli_output.success(f"Successfully deleted bot user {username}!")
