@@ -9,9 +9,10 @@ import click
 import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.config import Config
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 
 
-@click.command(name="get", short_help="Get a config value")
+@click.command(cls=TrackedCommand, name="get", short_help="Get a config value")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @click.argument("key")
 def config_get(options: GlobalOptions, key: str) -> None:
