@@ -7,25 +7,43 @@ import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.code_generation import (  # import the *package* containing the tf files
     approval,
 )
-from sym.flow.cli.errors import NonEmptyDirectoryError, NotLoggedInError
+from sym.flow.cli.errors import NotLoggedInError
 from sym.flow.cli.helpers.config import Config
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 
 
-@click.command(short_help="Generate starter Terraform code")
+@click.command(cls=TrackedCommand, short_help="Generate starter Terraform code")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @click.option(
     "--workspace-id",
-    prompt="Workspace ID",
+    prompt=f"Slack Workspace ID {click.style('(You can find this in Slack by running /sym whoami)', dim=True, italic=True)}",
 )
 def init(options: GlobalOptions, workspace_id: str) -> None:
-    """In an empty directory, generate the Terraform configuration needed to create a Sym approval-only Flow."""
+    """Generates the Terraform configuration needed to create a Sym approval-only Flow in a new directory."""
 
     if not Config.is_logged_in():
         raise NotLoggedInError()
 
-    if os.listdir("."):
-        raise NonEmptyDirectoryError()
+    cli_output.info(
+        "Welcome to Sym! This command will generate a new directory containing the Terraform and Python files needed "
+        "to configure your first Sym Flow.",
+        bold=True,
+    )
+
+    while True:
+        init_dir = click.prompt("What should we name the directory?", type=str, prompt_suffix="")
+
+        # Check if a file/directory already exists at the given path
+        if os.path.exists(init_dir):
+            cli_output.error(
+                f"Looks like the directory '{init_dir}' already exists! Please provide the name for a new directory."
+            )
+        else:
+            break
+
+    # Create the directory
+    os.makedirs(init_dir)
 
     # Note: The impl file is stored as a `.txt` resource because PyOxidizer (the tool used to package symflow CLI)
     # Does NOT support reading `.py` files with `importlib.resources`
@@ -39,13 +57,13 @@ def init(options: GlobalOptions, workspace_id: str) -> None:
     # These files don't need any values substituted in them.
     for resource_name, output_file in static_files:
         template = pkg_resources.read_text(approval, resource_name)
-        with open(output_file, "w") as f:
+        with open(f"{init_dir}/{output_file}", "w") as f:
             f.write(template)
 
     # Fill in the org slug and workspace ID variables with values
     org = Config.get_org().slug
     main_tf = pkg_resources.read_text(approval, "main.tf")
-    with open("main.tf", "w") as f:
+    with open(f"{init_dir}/main.tf", "w") as f:
         main_tf = main_tf.replace("${var.sym_org_slug}", org)
         main_tf = main_tf.replace("${var.slack_workspace_id}", workspace_id.upper())
 
@@ -54,6 +72,6 @@ def init(options: GlobalOptions, workspace_id: str) -> None:
     cli_output.info(
         "Successfully generated your Sym Terraform configuration! Run the following to check the configuration:"
     )
-    cli_output.success("terraform init && terraform plan")
+    cli_output.success(f"cd {init_dir} && terraform init && terraform plan")
     cli_output.info("\nWhen you are ready to apply your configuration, run the following:")
     cli_output.success("terraform apply")
