@@ -1,13 +1,14 @@
 import click
-import requests
 
 import sym.flow.cli.helpers.output as cli_output
-from sym.flow.cli.helpers.config import Config, store_login_config
+from sym.flow.cli.helpers.config import Config
 from sym.flow.cli.helpers.global_options import GlobalOptions
-from sym.flow.cli.helpers.jwt import JWT
 from sym.flow.cli.helpers.login.login_flow import BrowserRedirectFlow
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 
 
+# Note: This command deliberately does not define `cls=TrackedCommand`, as we track symflow logins when we
+# hit the auth/login API (sym_api.verify_login)
 @click.command(short_help="Log in to your Sym account")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @click.option(
@@ -19,7 +20,7 @@ from sym.flow.cli.helpers.login.login_flow import BrowserRedirectFlow
 @click.option(
     "--org-id",
     prompt="Org ID",
-    default=lambda: Config.instance().get("org"),
+    default=lambda: Config.get_org_slug(),
     help="The ID of the Organization you want to log in to.",
 )
 def login(options: GlobalOptions, port: int, org_id: str) -> None:
@@ -39,35 +40,17 @@ def login(options: GlobalOptions, port: int, org_id: str) -> None:
     Config.set_org(org)
 
     flow = BrowserRedirectFlow(port)
-
-    url, *_ = flow.gen_browser_login_params(options, org)
-    styled_url = click.style(requests.utils.requote_uri(url), bold=True)  # type: ignore
-    cli_output.info(
-        f"Opening the login page in your browser. If this doesn't work, please visit the following URL:"
-        + "\n"
-        + styled_url
-        + "\n"
-    )
-
-    # It's possible to not get an auth_token AND not have raised an exception before getting here
-    # if the user has just signed up.
-    if auth_token := flow.login(options, org):
-        options.set_access_token(auth_token["access_token"])
-        options.dprint(auth_token=auth_token)
-        cli_output.success("Login succeeded")
-
-        jwt = JWT.from_access_token(auth_token["access_token"], auth_url=options.auth_url)
-        store_login_config(jwt.email, org, auth_token)
+    flow.login(options, org)
 
 
-@click.command(short_help="Log out of your Sym account")
+@click.command(cls=TrackedCommand, short_help="Log out of your Sym account")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 def logout(options: GlobalOptions) -> None:
     if not Config.is_logged_in() and not options.access_token:
-        cli_output.fail("✖ You are already logged out!")
+        cli_output.fail("You are already logged out!")
 
     if options.access_token:
-        cli_output.fail("✖ You are logged in via SYM_JWT, you must unset SYM_JWT manually")
+        cli_output.fail("You are logged in via SYM_JWT, you must unset SYM_JWT manually")
 
     if Config.is_logged_in():
         Config.logout()
