@@ -1,11 +1,10 @@
 import click
-from sym.shared.cli.helpers.sym_group import SymGroup
 
 from sym.flow.cli.commands.resources.list import resources_list
 from sym.flow.cli.helpers.global_options import GlobalOptions
 
 
-@click.group(name="resources", cls=SymGroup, short_help="Perform operations on Sym resources")
+@click.group(name="resources", short_help="Perform operations on Sym resources")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 def resources(options: GlobalOptions) -> None:
     """Operations on resources (e.g. sym_flow)
