@@ -6,10 +6,11 @@ from tabulate import tabulate
 import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.api import SymAPI
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 from sym.flow.cli.models.service import Service
 
 
-@click.command(name="list", short_help="View all services")
+@click.command(cls=TrackedCommand, name="list", short_help="View all services")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 def services_list(options: GlobalOptions) -> None:
     """View all Services currently set up for your organization."""
