@@ -5,9 +5,10 @@ import click
 import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.commands.users.utils import get_or_prompt_service
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 
 
-@click.command(name="update", short_help="Update an existing service")
+@click.command(cls=TrackedCommand, name="update", short_help="Update an existing service")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 @click.option(
     "--service-type",
