@@ -2,12 +2,14 @@ import click
 
 import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 from sym.flow.cli.models import ServiceType
 from sym.flow.cli.models.service import BaseService
 from sym.flow.cli.models.user import CSVMatcher
 
 
 @click.command(
+    cls=TrackedCommand,
     name="delete",
     short_help="Delete a User",
 )
