@@ -6,10 +6,11 @@ from tabulate import tabulate
 import sym.flow.cli.helpers.output as cli_output
 from sym.flow.cli.helpers.api import SymAPI
 from sym.flow.cli.helpers.global_options import GlobalOptions
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 from sym.flow.cli.helpers.utils import human_friendly, utc_to_local
 
 
-@click.command(name="list", short_help="List all Users")
+@click.command(cls=TrackedCommand, name="list", short_help="List all Users")
 @click.make_pass_decorator(GlobalOptions, ensure=True)
 def users_list(options: GlobalOptions) -> None:
     """Lists all Users in your organization."""
