@@ -4,9 +4,10 @@ import click
 
 from sym.flow.cli.helpers.global_options import GlobalOptions
 from sym.flow.cli.helpers.profile_operations import update_full_name
+from sym.flow.cli.helpers.tracked_command import TrackedCommand
 
 
-@click.command(name="update-name", short_help="Update a User's name")
+@click.command(cls=TrackedCommand, name="update-name", short_help="Update a User's name")
 @click.argument("email", required=True, type=str)
 @click.argument("full_name", required=True, type=str, nargs=-1)
 @click.make_pass_decorator(GlobalOptions, ensure=True)
