@@ -1,15 +1,19 @@
-SegmentWriteKey = "awgf20oKYlsxq73mW6lO6iVyCOgepPIr"
+from enum import Enum
+
 SentryDSN = "https://6a8722276347467b801e5aa152a48ed1@o373009.ingest.sentry.io/5462801"
 
 DEFAULT_API_URL = "https://api.symops.com/api/v1"
 DEFAULT_AUTH_URL = "https://auth.symops.com"
 
-WRITE_ONLY_AWS_ACCESS_KEY_ID = "AKIA23WDB56I6QOC4ZAR"
-WRITE_ONLY_AWS_SECRET_ACCESS_KEY = "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"
-
-DROPBOX_BUCKET = "sym-dropbox-us-east-1"
-
 CLI_PACKAGE_NAME = "sym-flow-cli"
 
 SYM_DOCUMENTATION_URL = "https://docs.symops.com/"
 SYM_SUPPORT_EMAIL = "support@symops.com"
+
+
+class SegmentTrackStatus(str, Enum):
+    """Accepted statuses for the segment_track Sym API call."""
+
+    INVOKED = "invoked"
+    SUCCESS = "success"
+    ERROR = "error"
